@@ -24,13 +24,14 @@ private:
     FMH::FileLoader *m_fileLoader;
     FMH::MODEL_LIST list;  
 
-    void setList();
+    void setList(const QStringList &sources);
 
 public slots:
     bool remove(const int &index);
     bool deleteAt(const int &index);
     bool bookmark(const int &index, const int &value);
     void clear();
+    void rescan();
 };
 
 #endif // LIBRARYMODEL_H
